Package: RKorAPClient
Type: Package
Title: 'KorAP' Web Service Client Package
Version: 1.2.1
Authors@R: 
    c(person(given = "Marc",
             family = "Kupietz",
             role = c("aut", "cre"),
             email = "kupietz@ids-mannheim.de"),
      person(given = "Nils",
             family = "Diewald",
             role = c("ctb"),
             email = "diewald@ids-mannheim.de"),
      person(given = "Leibniz Institute for the German Language",
             role = c("cph", "fnd")))
Description: A client package that makes the 'KorAP' web service API accessible from R. The corpus analysis platform 'KorAP' has been developed as a scientific tool to make potentially large, stratified and multiply annotated corpora, such as the 'German Reference Corpus DeReKo' or the 'Corpus of the Contemporary Romanian Language CoRoLa', accessible for linguists to let them verify hypotheses and to find interesting patterns in real language use. The 'RKorAPClient' package provides access to 'KorAP' and the corpora behind it for user-created R code, as a programmatic alternative to the 'KorAP' web user-interface. You can learn more about 'KorAP' and use it directly on 'DeReKo' at <https://korap.ids-mannheim.de/>.
Depends: R (>= 4.1.0)
Language: en-US
License: BSD_2_clause + file LICENSE
URL: https://github.com/KorAP/RKorAPClient/,
        https://korap.ids-mannheim.de/,
        https://www.ids-mannheim.de/digspra/kl/projekte/korap
BugReports: https://github.com/KorAP/RKorAPClient/issues
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: R.cache, broom, ggplot2, tibble, magrittr, tidyr, dplyr,
        lubridate, highcharter, jsonlite, keyring, utils, httr2, curl,
        methods, PTXQC, purrr, stringr, urltools, xml2
Suggests: lifecycle, testthat, tidyllm, htmlwidgets, rmarkdown, shiny,
        vcd, kableExtra, knitr, purrrlyr, raster, tidyverse, sf,
        geojsonsf, viridisLite
Collate: 'logging.R' 'KorAPConnection.R' 'KorAPCorpusStats.R'
        'RKorAPClient-package.R' 'KorAPQuery.R' 'association-scores.R'
        'ci.R' 'collocationAnalysis.R' 'collocationScoreQuery.R'
        'hc_add_onclick_korap_search.R' 'hc_freq_by_year_ci.R' 'misc.R'
        'reexports.R' 'textMetadata.R'
NeedsCompilation: no
Packaged: 2025-10-09 15:10:39 UTC; kupietz
Author: Marc Kupietz [aut, cre],
  Nils Diewald [ctb],
  Leibniz Institute for the German Language [cph, fnd]
Maintainer: Marc Kupietz <kupietz@ids-mannheim.de>
Repository: CRAN
Date/Publication: 2025-10-09 16:00:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:50:49 UTC; unix
